==> vtk-7.1.1-4-armv7h.pkg.tar.xz: vtk/vtkMPIController.java <==
// java wrapper for vtkMPIController object
//

package vtk;
import vtk.*;

public class vtkMPIController extends vtkMultiProcessController
{

  private native String GetClassName_0();
  public String GetClassName()
    { return GetClassName_0(); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native void Initialize_2();
  public void Initialize()
    { Initialize_2(); }

  private native void Finalize_3();
  public void Finalize()
    { Finalize_3(); }

  private native void Finalize_4(int id0);
  public void Finalize(int id0)
    { Finalize_4(id0); }

  private native void SingleMethodExecute_5();
  public void SingleMethodExecute()
    { SingleMethodExecute_5(); }

  private native void MultipleMethodExecute_6();
  public void MultipleMethodExecute()
    { MultipleMethodExecute_6(); }

  private native void CreateOutputWindow_7();
  public void CreateOutputWindow()
    { CreateOutputWindow_7(); }

  private native String ErrorString_8(int id0);
  public String ErrorString(int id0)
    { return ErrorString_8(id0); }

  private native void SetCommunicator_9(vtkMPICommunicator id0);
  public void SetCommunicator(vtkMPICommunicator id0)
    { SetCommunicator_9(id0); }

  private native long CreateSubController_10(vtkProcessGroup id0);
  public vtkMPIController CreateSubController(vtkProcessGroup id0) {
    long temp = CreateSubController_10(id0);

    if (temp == 0) return null;
    return (vtkMPIController)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native long PartitionController_11(int id0,int id1);
  public vtkMPIController PartitionController(int id0,int id1) {
    long temp = PartitionController_11(id0,id1);

    if (temp == 0) return null;
    return (vtkMPIController)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native String GetProcessorName_12();
  public String GetProcessorName()
    { return GetProcessorName_12(); }

  private native void SetUseSsendForRMI_13(int id0);
  public void SetUseSsendForRMI(int id0)
    { SetUseSsendForRMI_13(id0); }

  private native int GetUseSsendForRMI_14();
  public int GetUseSsendForRMI()
    { return GetUseSsendForRMI_14(); }

  public vtkMPIController() { super(); }

  public vtkMPIController(long id) { super(id); }
  public native long   VTKInit();

}

==> vtk-8.2.0-21-armv7h.pkg.tar.xz: vtk/vtkMPIController.java <==
// java wrapper for vtkMPIController object
//

package vtk;
import vtk.*;

public class vtkMPIController extends vtkMultiProcessController
{

  private native int IsTypeOf_0(String id0);
  public int IsTypeOf(String id0)
    { return IsTypeOf_0(id0); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native void Initialize_2();
  public void Initialize()
    { Initialize_2(); }

  private native void Finalize_3();
  public void Finalize()
    { Finalize_3(); }

  private native void Finalize_4(int id0);
  public void Finalize(int id0)
    { Finalize_4(id0); }

  private native void SingleMethodExecute_5();
  public void SingleMethodExecute()
    { SingleMethodExecute_5(); }

  private native void MultipleMethodExecute_6();
  public void MultipleMethodExecute()
    { MultipleMethodExecute_6(); }

  private native void CreateOutputWindow_7();
  public void CreateOutputWindow()
    { CreateOutputWindow_7(); }

  private native String ErrorString_8(int id0);
  public String ErrorString(int id0)
    { return ErrorString_8(id0); }

  private native void SetCommunicator_9(vtkMPICommunicator id0);
  public void SetCommunicator(vtkMPICommunicator id0)
    { SetCommunicator_9(id0); }

  private native long CreateSubController_10(vtkProcessGroup id0);
  public vtkMPIController CreateSubController(vtkProcessGroup id0) {
    long temp = CreateSubController_10(id0);

    if (temp == 0) return null;
    return (vtkMPIController)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native long PartitionController_11(int id0,int id1);
  public vtkMPIController PartitionController(int id0,int id1) {
    long temp = PartitionController_11(id0,id1);

    if (temp == 0) return null;
    return (vtkMPIController)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native String GetProcessorName_12();
  public String GetProcessorName()
    { return GetProcessorName_12(); }

  private native void SetUseSsendForRMI_13(int id0);
  public void SetUseSsendForRMI(int id0)
    { SetUseSsendForRMI_13(id0); }

  private native int GetUseSsendForRMI_14();
  public int GetUseSsendForRMI()
    { return GetUseSsendForRMI_14(); }

  public vtkMPIController() { super(); }

  public vtkMPIController(long id) { super(id); }
  public native long   VTKInit();

}
